<?xml version="1.0"?>
<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="ShowImg" version="0.9.5">
<MenuBar>
	<Menu name="file" >
		<Action name="create_new_items"/>
		<Action name="window_new"/>
		<Action name="fileopen"/>
		<Action name="filesave"/>
		<Action name="filesaveas"/>
		<Separator/>
		<Menu name="Import"><text>&amp;Import</text>
			<Action name="album_addImages" />
			<ActionList name="file_actions_import"/>
		</Menu>
		<Menu name="Export"><text>&amp;Export</text>
			<ActionList name="file_actions_export"/>
		</Menu>
		<Separator/>
		<Action name="fileprint" />
		<Separator/>
		<Action name="close"/>
		<Action name="exit"/>
	</Menu>

	<Menu name="edit" >
	    <Action name="editcut" />
	    <Action name="editcopy" />
	    <Action name="editcopypixmap"/>
	    <Action name="editpaste"/>
	    <Separator/>
	    <Action name="rename"/>
	    <Separator/>
	    <Action name="edittrash"/>
	    <Action name="editdelete"/>
	    <Action name="editshred"/>
	    <Separator/>
	    <Action name="Edit File Type"/>
	    <Action name="Image Info"/>
	    <Action name="Dir Properties"/>
	    <Separator/>
	    <Action name="SelectAll"/>
	    <Action name="Unselect All"/>
	    <Action name="Invert Selection"/>
	</Menu>

	<Action name="action go"/>

	<Menu name="view" >
	    <Action name="view_zoomm"/>
	    <Action name="view_Orientation"/>
	    <Action name="view_effects"/>
	    <Separator/>
            <Menu name="window"><text>&amp;Windows</text>
                <ActionList name="winlist"/>
	    </Menu>
	    <Action name="view_sort"/>
	    <Action name="view_icons"/>
		<Action name="dirview details"/>
		<Action name="FullScreen"/>
	    <Action name="Slideshow"/>
	    <Separator/>
	    <Action name="Refresh"/>
	    <Action name="Stop"/>
	</Menu>

	<Menu name="Image" > <text>&amp;Image</text>
	    <Action name="view_wallp"/>
	    <Separator />
              <ActionList name="image_actions"/>
	</Menu>

	<Action name="bookm"/>

	<Menu name="Tools"> <text>&amp;Tools</text>
		<Action name="tools_maint"/>
	    <Action name="tools_campare"/>
	    <Action name="tools_conv"/>
		<Menu name="BatchProcesses"><text>&amp;Batch Processes</text>
			<Action name="Rename series"/>
			<ActionList name="batch_actions"/>
		</Menu>
		<Action name="scanimage"/>
	    <ActionList name="album_actions"/>
	    <ActionList name="tool_actions"/>

	</Menu>

	<Menu name="settings">
		<Action name="configure_tools" append="configure_merge" />
		<Action name="configure_interface" />
	</Menu>

	<Menu name="help"> <text>&amp;Help</text>
	    <Action name="time"/>
	    <Action name="help_showimgtipofday"/>
	</Menu>
</MenuBar>

<ToolBar name="mainToolBar"  noMerge="1">
	<text>Main Toolbar</text>
	<Action name="goUp" />
	<Action name="back" />
	<Action name="forward"/>
	<Action name="goHome"/>
	<Separator lineSeparator="true"/>
	<Action name="editcut"/>
	<Action name="editcopy"/>
	<Action name="editpaste"/>
	<Separator lineSeparator="true"/>
	<Action name="Rotate Left"/>
	<Action name="Rotate Right"/>
	<Action name="Flip"/>
	<Action name="Mirror"/>
	<Separator lineSeparator="true"/>
	<Action name="Slideshow"/>
	<Action name="Previous Image"/>
	<Action name="Next Image"/>
	<Separator lineSeparator="true"/>
	<Action name="Refresh"/>
	<Action name="Preview"/>
	<Action name="Stop"/>
 </ToolBar>

<ToolBar name="viewToolBar" >
	<text>View Toolbar</text>
	<Action name="FullScreen"/>
	<Separator lineSeparator="true"/>
	<Action name="Zoom in"/>
	<Action name="zoomComboAction"/>
	<Action name="Zoom out"/>
	<Action name="Fit the width"/>
	<Action name="Fit the height"/>
	<Action name="Fit to Screen"/>
	<Action name="Originale size"/>
	<Action name="ZoomLock"/>
	<Separator lineSeparator="true"/>
	<Action name="Enlarge"/>
	<Action name="Shrink"/>
	<Separator lineSeparator="true"/>
 </ToolBar>

<ToolBar name="locationToolBar" fullWidth="true">
  <text>Location Toolbar</text>
  <Action name="clear_location" />
  <Action name="location_label" />
  <Action name="location_url" />
  <Action name="location_go" />
</ToolBar>

<ToolBar name="fileViewToolBar" noMerge="1">
  <text>File View Toolbar</text>
	<Action name="dirview create_new_items"/>
	<Separator lineSeparator="true"/>
	<Action name="goUp" />
	<Action name="Previous Directory" />
	<Action name="Next Directory"/>
	<Action name="goHome"/>
	<Action name="Dir Properties"/>
</ToolBar>

<ToolBar name="CatViewToolBar" noMerge="1"  fullWidth="true" newline="true" iconText="true">
  <text>Category View Toolbar</text>
	<Action name="editnewcategory" />
	<Separator/>
	<Action name="editcatrename" />
	<Action name="editcatdelete"/>
	<Action name="Cat Properties"/>
	<Separator/>
	<Action name="category selection or" />
	<Action name="category selection and" />
	<Separator/><MergeLocal/>
	<Action name="categoryview currentAction" />
</ToolBar>

<ToolBar name="CdarcViewToolBar" noMerge="1">
  <text>CDArchive View Toolbar</text>
	<Action name="editnewcdarchive"/>
	<Separator lineSeparator="true"/>
	<Action name="cdarchive editdirrename"/>
	<Action name="cdarchive editdirtrash"/>
	<Action name="cdarchive Properties"/>
</ToolBar>

<StatusBar/>


</kpartgui>
<!--  //-->
