( cd usr/share/doc/HTML/it/showimg ; rm -rf common )
( cd usr/share/doc/HTML/it/showimg ; ln -sf /usr/share/doc/HTML/it/common common )
( cd usr/share/doc/HTML/ru/showimg ; rm -rf common )
( cd usr/share/doc/HTML/ru/showimg ; ln -sf /usr/share/doc/HTML/ru/common common )
( cd usr/share/doc/HTML/es/showimg ; rm -rf common )
( cd usr/share/doc/HTML/es/showimg ; ln -sf /usr/share/doc/HTML/es/common common )
( cd usr/share/doc/HTML/pt/showimg ; rm -rf common )
( cd usr/share/doc/HTML/pt/showimg ; ln -sf /usr/share/doc/HTML/pt/common common )
( cd usr/share/doc/HTML/da/showimg ; rm -rf common )
( cd usr/share/doc/HTML/da/showimg ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/sv/showimg ; rm -rf common )
( cd usr/share/doc/HTML/sv/showimg ; ln -sf /usr/share/doc/HTML/sv/common common )
( cd usr/share/doc/HTML/en/showimg ; rm -rf common )
( cd usr/share/doc/HTML/en/showimg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/fr/showimg ; rm -rf common )
( cd usr/share/doc/HTML/fr/showimg ; ln -sf /usr/share/doc/HTML/fr/common common )
( cd usr/share/doc/HTML/et/showimg ; rm -rf common )
( cd usr/share/doc/HTML/et/showimg ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/lib ; rm -rf libshowimgkexidbparser.so.1 )
( cd usr/lib ; ln -sf libshowimgkexidbparser.so.1.0.0 libshowimgkexidbparser.so.1 )
( cd usr/lib ; rm -rf libshowimgkexidbparser.so )
( cd usr/lib ; ln -sf libshowimgkexidbparser.so.1.0.0 libshowimgkexidbparser.so )
( cd usr/lib ; rm -rf libshowimgkexidb.so.0 )
( cd usr/lib ; ln -sf libshowimgkexidb.so.0.0.0 libshowimgkexidb.so.0 )
( cd usr/lib ; rm -rf libshowimgkexiutils.so.1 )
( cd usr/lib ; ln -sf libshowimgkexiutils.so.1.0.0 libshowimgkexiutils.so.1 )
( cd usr/lib ; rm -rf libshowimgkexiutils.so )
( cd usr/lib ; ln -sf libshowimgkexiutils.so.1.0.0 libshowimgkexiutils.so )
( cd usr/lib ; rm -rf libshowimgkexidb.so )
( cd usr/lib ; ln -sf libshowimgkexidb.so.0.0.0 libshowimgkexidb.so )
( cd usr/lib ; rm -rf libshowimgkexisql3.so.3 )
( cd usr/lib ; ln -sf libshowimgkexisql3.so.3.0.0 libshowimgkexisql3.so.3 )
( cd usr/lib ; rm -rf libshowimgkexisql2.so.2 )
( cd usr/lib ; ln -sf libshowimgkexisql2.so.2.0.8 libshowimgkexisql2.so.2 )
( cd usr/lib ; rm -rf libshowimgcore.so.0 )
( cd usr/lib ; ln -sf libshowimgcore.so.0.0.9 libshowimgcore.so.0 )
( cd usr/lib ; rm -rf libshowimgkexisql3.so )
( cd usr/lib ; ln -sf libshowimgkexisql3.so.3.0.0 libshowimgkexisql3.so )
( cd usr/lib ; rm -rf libshowimgkexisql2.so )
( cd usr/lib ; ln -sf libshowimgkexisql2.so.2.0.8 libshowimgkexisql2.so )
( cd usr/lib ; rm -rf libshowimgcore.so )
( cd usr/lib ; ln -sf libshowimgcore.so.0.0.9 libshowimgcore.so )
